fam.bernoulli()
fam.poisson()
fam.zero.truncated.poisson()
fam.normal.location.scale()
fam.multinomial(dimension)"astfam" giving name and values of any
hyperparameters.
"bernoulli"This distribution has degenerate limiting distributions. The lower limit as $theta to minus infinity$ is the distribution concentrated at zero, having cumulant function which is the constant function everywhere equal to zero. The upper limit as $theta to plus infinity$ is the distribution concentrated at one, having cumulant function which is the identity function satisfying $c(theta) = theta$ for all $theta$.
For predecessor (sample size) $n$, the successor is the sum of $n$ independent and identically distributed (IID) Bernoulli random variables, that is, binomial with sample size $n$. The mean value parameter is $n$ times the mean value parameter for sample size one; the cumulant function is $n$ times the cumulant function for sample size one; the canonical parameter is the same for all sample sizes.
"poisson"This distribution has a degenerate limiting distribution. The lower limit as $theta to minus infinity$ is the distribution concentrated at zero, having cumulant function which is the constant function everywhere equal to zero. There is no upper limit because the canonical statistic is unbounded above.
For predecessor (sample size) $n$, the successor is the sum of $n$ IID Poisson random variables, that is, Poisson with mean $n mu$. The mean value parameter is $n$ times the mean value parameter for sample size one; the cumulant function is $n$ times the cumulant function for sample size one; the canonical parameter is the same for all sample sizes.
"zero.truncated.poisson"This distribution has a degenerate limiting distribution. The lower limit as $theta to minus infinity$ is the distribution concentrated at one, having cumulant function which is the identity function satisfying $c(theta) = theta$ for all $theta$. There is no upper limit because the canonical statistic is unbounded above.
For predecessor (sample size) $n$, the successor is the sum of $n$ IID zero-truncated Poisson random variables, which is not a brand-name distribution. The mean value parameter is $n$ times the mean value parameter for sample size one; the cumulant function is $n$ times the cumulant function for sample size one; the canonical parameter is the same for all sample sizes.
"normal.location.scale"This distribution has no degenerate limiting distributions, because the canonical statistic is a continuous random vector so the boundary of its support has probability zero.
For predecessor (sample size) $n$, the successor is the sum of $n$ IID random vectors $(x[i], x[i]^2)$, where each $x[i]$ is normal with mean $m$ and variance $v$, and this is not a brand-name multivariate distribution (the first component of the sum is normal, the second component noncentral chi-square, and the components are not independent). The mean value parameter vector is $n$ times the mean value parameter vector for sample size one; the cumulant function is $n$ times the cumulant function for sample size one; the canonical parameter vector is the same for all sample sizes.
"multinomial"This distribution is degenerate. The sum of the components of the canonical statistic is equal to one with probability one, which implies the nonidentifiability of the $d$-dimensional canonical parameter vector mentioned above. Hence one parameter (at least) is always constrained to to be zero in fitting an aster model with a multinomial family.
This distribution has many degenerate distributions. For any vector $delta$ the limit of distributions having canonical parameter vectors $theta + s delta$ as $s to infinity$ exists and is another multinomial distribution (the limit distribution in the direction $delta$). Let $A$ be the set of $i$ such that $delta[i] = max(delta)$, where $max(delta)$ denotes the maximum over the components of $delta$. Then the limit distribution in the direction $delta$ has components $Y[i]$ of the canonical statistic for $i not in A$ concentrated at zero. The cumulant function of this degenerate distribution is $$c(\theta) = \log\left(\sum_{j \in A} e^{\theta_j}\right).$$ The canonical parameters $theta[j]$ for $j not in A$ are not identifiable, and one other canonical parameter is not identifiable because of the constrant that the sum of the components of the canonical statistic is equal to one with probability one.
For predecessor (sample size) $n$, the successor is the sum of $n$ IID multinomial-sample-size-one random vectors, that is, multinomial with sample size $n$. The mean value parameter is $n$ times the mean value parameter for sample size one; the cumulant function is $n$ times the cumulant function for sample size one; the canonical parameter is the same for all sample sizes.
fam.bernoulli()
fam.multinomial(4)
Run the code above in your browser using DataLab